@@ -6,14 +6,14 @@ describe 'basic nova' do
 
     it 'should work with no errors' do
       pp= <<-EOS
-      include ::openstack_integration
-      include ::openstack_integration::repos
-      include ::openstack_integration::rabbitmq
-      include ::openstack_integration::mysql
-      include ::openstack_integration::keystone
-      include ::openstack_integration::neutron
-      include ::openstack_integration::placement
-      include ::openstack_integration::nova
+      include openstack_integration
+      include openstack_integration::repos
+      include openstack_integration::rabbitmq
+      include openstack_integration::mysql
+      include openstack_integration::keystone
+      include openstack_integration::neutron
+      include openstack_integration::placement
+      include openstack_integration::nova
 
       nova_aggregate { 'test_aggregate':
         ensure            => present,
@@ -58,7 +58,7 @@ describe 'basic nova' do
     end
 
     describe cron do
-      it { is_expected.to have_entry('1 0 * * * nova-manage db archive_deleted_rows  --max_rows 100  >>/var/log/nova/nova-rowsflush.log 2>&1').with_user('nova') }
+      it { is_expected.to have_entry('1 0 * * * nova-manage db archive_deleted_rows  --max_rows 100    >>/var/log/nova/nova-rowsflush.log 2>&1').with_user('nova') }
     end
 
     describe 'nova aggregate' do
