@@ -4,7 +4,7 @@ describe 'nova::api' do
 
   let :pre_condition do
     "include nova
-     class { '::nova::keystone::authtoken':
+     class { 'nova::keystone::authtoken':
        password => 'passw0rd',
      }"
   end
@@ -44,6 +44,8 @@ describe 'nova::api' do
 
       it { is_expected.to contain_nova_config('DEFAULT/instance_name_template').with_ensure('absent')}
 
+      it { is_expected.to contain_class('nova::availability_zone') }
+
       it 'configures various stuff' do
         is_expected.to contain_nova_config('wsgi/api_paste_config').with('value' => 'api-paste.ini')
         is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen').with('value' => '0.0.0.0')
@@ -174,7 +176,7 @@ describe 'nova::api' do
     context 'with default database parameters' do
       let :pre_condition do
         "include nova
-         class { '::nova::keystone::authtoken':
+         class { 'nova::keystone::authtoken':
            password => 'a_big_secret',
          }"
       end
@@ -195,7 +197,7 @@ describe 'nova::api' do
            api_slave_connection    => 'mysql://user:pass@slave/db2',
            database_idle_timeout   => '30',
          }
-         class { '::nova::keystone::authtoken':
+         class { 'nova::keystone::authtoken':
            password => 'passw0rd',
          }
         "
@@ -227,9 +229,9 @@ describe 'nova::api' do
       end
 
       let :pre_condition do
-        "include ::apache
-         include ::nova
-         class { '::nova::keystone::authtoken':
+        "include apache
+         include nova
+         class { 'nova::keystone::authtoken':
            password => 'a_big_secret',
          }"
       end
@@ -255,9 +257,9 @@ describe 'nova::api' do
       end
 
       let :pre_condition do
-        "include ::apache
-         include ::nova
-         class { '::nova::keystone::authtoken':
+        "include apache
+         include nova
+         class { 'nova::keystone::authtoken':
            password => 'a_big_secret',
          }"
       end
@@ -280,9 +282,9 @@ describe 'nova::api' do
       end
 
       let :pre_condition do
-        "include ::apache
-         include ::nova
-         class { '::nova::keystone::authtoken':
+        "include apache
+         include nova
+         class { 'nova::keystone::authtoken':
            password => 'a_big_secret',
          }"
       end
@@ -313,9 +315,9 @@ describe 'nova::api' do
       end
 
       let :pre_condition do
-        "include ::apache
-         include ::nova
-         class { '::nova::keystone::authtoken':
+        "include apache
+         include nova
+         class { 'nova::keystone::authtoken':
            password => 'a_big_secret',
          }"
       end
