@@ -68,8 +68,10 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/nfs_mount_options').with_ensure('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/num_pcie_ports').with_ensure('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/mem_stats_period_seconds').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_libvirtd_config('log_outputs').with_ensure('absent')}
       it { is_expected.to contain_libvirtd_config('log_filters').with_ensure('absent')}
       it { is_expected.to contain_libvirtd_config('tls_priority').with_ensure('absent')}
+      it { is_expected.to contain_libvirtd_config('pmem_namespaces').with_ensure('<SERVICE DEFAULT>')}
     end
 
     describe 'with params' do
@@ -102,6 +104,7 @@ describe 'nova::compute::libvirt' do
           :mem_stats_period_seconds                   => 20,
           :log_filters                                => '1:qemu',
           :tls_priority                               => 'NORMAL:-VERS-SSL3.0',
+          :pmem_namespaces                            => '128G:ns0|ns1|ns2|ns3'
         }
       end
 
@@ -133,6 +136,7 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/mem_stats_period_seconds').with_value(20)}
       it { is_expected.to contain_libvirtd_config('log_filters').with_value("\"#{params[:log_filters]}\"")}
       it { is_expected.to contain_libvirtd_config('tls_priority').with_value("\"#{params[:tls_priority]}\"")}
+      it { is_expected.to contain_libvirtd_config('pmem_namespaces').with_value("128G:ns0|ns1|ns2|ns3")}
       it {
         is_expected.to contain_service('libvirt').with(
           :name     => 'custom_service',
